unit Unit1;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, TAGraph, TASeries, TALegendPanel, TASources,
  TATools, Forms, Controls, Graphics, Dialogs, StdCtrls, Menus, ExtCtrls;

type

  { TForm1 }

  TForm1 = class(TForm)
    ButtonSimuStart: TButton;
    ButtonBeenden: TButton;
    Chart1: TChart;
    ComboBoxSpannung: TComboBox;
    Label15: TLabel;
    PzuSeries: TLineSeries;
    PabSeries: TLineSeries;
    PgSeries: TLineSeries;
    ComboBoxMaterial: TComboBox;

    EditTC: TEdit;
    Editl: TEdit;
    Editd: TEdit;
    Label1: TLabel;
    Label12: TLabel;
    Label13: TLabel;
    Label14: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    Label8: TLabel;
    Label9: TLabel;
    Label10: TLabel;
    Label11: TLabel;
    Memo1: TMemo;
    Shape1: TShape;


    procedure ButtonBeendenClick(Sender: TObject);
    procedure ButtonSimuStartClick(Sender: TObject);
    procedure ComboBoxMaterialChange(Sender: TObject);

    procedure ComboBoxSpannungChange(Sender: TObject);


  private
    { private declarations }
  public
    { public declarations }
  end;

CONST
     SBK = 0.000000056704    {Stefan-Boltzmann-Konstante in W/m^2*K^4};
     Tck = 273.15            {Umrechnung von °C auf K};
     deltat = 0.000001       {Zeitschritt in s};
     Rhalte = 3.5            {Widerstand des Haltedrahtes in Ohm};
     Pi = 3.14159265         {Kreiszahl Pi};

     {Materialkonstanten Wolfram}
     RspeW = 0.0000000528    {spezifischer Widerstand Wolfram in ohm/m bei 20°C};
     rhodW = 19300           {spezifische Dichte von Wolfram in kg/m^3};
     TschmelzW = 3695        {Schmelztemperatur Wolfram in K};
     lambdaW = 170           {Wärmeleitfähigkeit Wolfram in W/m*K};
     cW = 138                {spezifische Wärmekapazität Wolfram in J/kg*K};
     TadkW = 0.0000045       {Temperaturausdehnungskoeffizient Wolfram in 1/K};
     alphaW = 0.0044         {Temperaturkoeffizient Wolfram in 1/K};

     {Materialkonstanten Platin}
     RspeP = 0.000000105     {spezifischer Widerstand Platin in ohm/m bei 20°C};
     rhodP = 21450           {spezifische Dichte von Platin in kg/m^3};
     TschmelzP = 2041.4      {Schmelztemperatur Platin in K};
     lambdaP = 72            {Wärmeleitfähigkeit Platin in W/m*K};
     cP = 130                {spezifische Wärmekapazität Platin in J/kg*K};
     TadkP = 0.0000088       {Temperaaturausdehnungskoeffizient Platin in 1/K};
     alphaP = 0.0031         {Temperaturkoeffizient Platin in 1/K};

var
     Form1: TForm1;   {Wichtig, gibt an dass Formular1 zur Unit gehört}

     {Spezifische Materialeigenschaften}
     RspeD  : single         {spezifischer Widerstand Draht in ohm/m bei 20°C};
     rhodD  : integer        {spezifische Dichte von Draht in kg/m^3};
     TschmD : single         {Schmelztemperatur Draht in K};
     lambdaD: integer        {Wärmeleitfähigkeit Draht in W/m*K};
     cD     : integer        {spezifische Wärmekapazität Draht in J/kg*K};
     TadkD  : single         {Temperaturausdehnungskoeffizient Draht in 1/K};
     alphaD : single         {Temperaturkoeffizient Draht in 1/K};

     {Drahtgeometrie}
     l      : single         {Länge Draht in m};
     d      : single         {Durchmesser Draht in m};
     Ob     : single         {Oberfläche Draht in m^2};
     A      : single         {Querschnittsfläche Draht in m^2};
     md     : single         {Masse Draht in kg};

     {Elektrische Eigenschaften Draht}
     Rd     : single         {Widerstand Draht in Ohm};
     Rel    : single         {Elektrischer Widerstand Draht bei T};
     RT     : single         {spezifischer elektrischer Widerstand Draht in Abhängigkeit von T};

     {Temperatureigenschaften}
     TC     : single         {Temperatur Raum/Draht in °C};
     TK     : single         {Temperatur Draht in K};
     Td     : single         {Temperaturdifferenz Raum-Draht in K};
     Temp   : single         {Temperatur Draht in Abhängigkeit der Zeit};
     Ter    : single         {Erwärmung Draht};

     {Elektrische Eigenschaften}
     Ug     : single         {Angelegte Spannung in V};
     U      : single         {Spannung die am Draht anliegt in V};
     I      : single         {Stromstärke die am Draht anliegt A};
     Pzu    : extended         {Leistung im Draht in W};
     Pab    : extended         {abgestrahlte Leistung in W};
     Pg     : extended         {Aufgenommene Leistung ingesamt in W};

     t      : Longint         {Zeitpunkt nach dem Einschalten in s};


implementation

{$R *.lfm}

{ TForm1 }

{SPANNUNGSEINGABE}
procedure TForm1.ComboBoxSpannungChange(Sender: TObject);
begin
  begin
  Case ComboboxSpannung.itemindex OF
       0   : Ug := 1.5 ;
       1   : Ug := 3   ;
       2   : Ug := 6   ;
       3   : Ug := 12  ;
       4   : Ug := 20  ;
       5   : Ug := 30  ;
       6   : Ug := 40  ;
       7   : Ug := 50  ;
       8   : Ug := 60  ;
       9   : Ug := 70  ;
       10  : Ug := 80  ;
       11  : Ug := 90  ;
       12  : Ug := 100 ;
       13  : Ug := 120 ;
       14  : Ug := 150 ;
       15  : Ug := 170 ;
       16  : Ug := 200 ;
       17  : Ug := 230 ;end;
  end;
end;



{MATERIALEINGABE}
procedure TForm1.ComboBoxMaterialChange(Sender: TObject);
begin
  If ComboBoxMaterial.itemindex = 0 Then
     begin
     RspeD   := RspeW          {spezifischer Widerstand Wolfram in ohm/m};
     rhodD   := rhodW          {spezifische Dichte von Wolfram in kg/m^3};
     TschmD  := TschmelzW      {Schmelztemperatur Wolfram in K};
     lambdaD := lambdaW        {Wärmeleitfähigkeit Wolfram in W/m*K};
     cD      := cW             {spezifische Wärmekapazität Wolfram in J/kg*K};
     TadkD   := TadkW          {Temperaturausdehnungskoeffizient Wolfram in 1/K};
     alphaD  := alphaW         {Temperaturkoeffizient Wolfram in 1/K};
     end;

  If ComboboxMaterial.itemindex = 1 Then
     begin
     RspeD   := RspeP          {spezifischer Widerstand Platin in ohm/m};
     rhodD   := rhodP          {spezifische Dichte von Platin in kg/m^3};
     TschmD  := TschmelzP      {Schmelztemperatur Platin in K};
     lambdaD := lambdaP        {Wärmeleitfähigkeit Platin in W/m*K};
     cD      := cP             {spezifische Wärmekapazität Platin in J/kg*K};
     TadkD   := TadkP          {Temperaturausdehnungskoeffizient Platin in 1/K};
     alphaD  := alphaP         {Temperaturkoeffizient Platin in 1/K};
end;

end;

{Aktion nach dem Drücken des "Beenden"-Buttons}
procedure TForm1.ButtonBeendenClick(Sender: TObject);
begin
  application.terminate;
end;

{Aktion nach dem Drücken des "Simu. Start."-Buttons}
procedure TForm1.ButtonSimuStartClick(Sender: TObject);
begin
  l    := StrToFloat(Editl.text);
  d    := StrtoFloat(Editd.text);
  TC   := StrtoFloat(EditTC.text);

  Ob   := pi*(d*0.001)*(l*0.001);
  Label9.Caption := FloattoStrF(Ob, fffixed,8,10);{Ausgabe mit 8 Stellen vor und 10 Stellen nach dem Komma}

  A    := pi*((d*0.001)/2)*((d*0.001)/2);
  Label7.Caption := FloattoStrF(A, fffixed,8,10); {Ausgabe Querschnitt}

  md   :=rhodD*A*(l*0.001);
  Label11.Caption := FloattoStrF(md, fffixed,8,10);{Augabe der Masse}

  For t:=1 To 2400 do
  begin
       {Formeln zur Abschließenden Berechnung}
       TK   := TC+273.15;
       Ter  := (Pg*(t*0.001))/(md*cd);
       Temp := TK+Ter;
       RT   := RSpeD*(1+alphaD*(Temp-293.15))*(l/A);
       U    := Ug;
       I    := U/RT;
       Pzu  := (U*U)/RT;
       Pab  := SBK*Ob*Temp*Temp*Temp*Temp;
       Pg   := Pzu-Pab;
       PgSeries.Addxy(t,Pg);
       PabSeries.Addxy(t,Pab);
       PzuSeries.Addxy(t,Pzu);
 Label15.caption:= FloattoSTrF(U,fffixed,8,10);
  end;

  end;





end.

